package cn.fw.hermes.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * 用户类型
 * 1 表示APP端
 * 0 表示小程序端
 */
public enum UserTypeEnum implements IEnum<Integer> {
    /**
     * APP端
     */
    B(1, "APP端"),
    /**
     * 小程序端
     */
    C(0, "小程序端"),

    /**
     * 系统账户
     */
    S(2,"系统账户");


    /**
     * 值
     */
    private final Integer value;
    /**
     * 类型
     */
    @Getter
    private final String name;

    UserTypeEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static UserTypeEnum ofValue(final Integer value) {
        for (final UserTypeEnum typeEnum : UserTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final UserTypeEnum typeEnum : UserTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }
}
