package cn.fw.hermes.controller.api.service;

import static cn.fw.common.web.util.ExceptionHandler.handleException;
import static cn.fw.common.web.util.ResultBuilder.failureWithMessage;
import static cn.fw.common.web.util.ResultBuilder.success;
import static cn.fw.hermes.common.constant.MessageStr.QUERY_FAILURE;
import cn.fw.data.base.domain.common.Message;
import cn.fw.hermes.sdk.api.ChatRecordApiService;
import cn.fw.hermes.sdk.api.para.ChatPullCondition;
import cn.fw.hermes.sdk.api.result.ChatUserDto;
import cn.fw.hermes.service.biz.ChatRecordBizService;
import java.util.List;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * @Author: Chenery
 * @Date: 2021/2/21 18:16
 */
@RestController
@Slf4j
@RequiredArgsConstructor
public class ChatPullApiServiceImpl implements ChatRecordApiService {

    private final ChatRecordBizService chatRecordBizService;

    @Override
    @GetMapping("/api/chat/record/count")
    public Message<List<ChatUserDto>> count(@RequestParam("chatCount") Integer chatCount) {
        final String msg = "统计单次聊天次数[/api/chat/record/count]";
        try {
            log.info("{} params[{}]", msg, chatCount);
            List<ChatUserDto> chatUserDtoList = chatRecordBizService.queryNumberOfChat(chatCount);
            return success(chatUserDtoList,
                    data -> log.info("{} 成功：result[{}]", msg, chatUserDtoList));
        } catch (Exception ex) {
            handleException(ex, e -> log.error("{} 失败: result[{}]", msg, e));
            return failureWithMessage(QUERY_FAILURE);
        }

    }

    @Override
    @PostMapping("/api/chat/record/pull")
    public Message<Integer> queryChatRecordOfCouple(
            @RequestBody ChatPullCondition chatPullCondition) {
        final String msg = "查询指定时间范围内两人聊天次数[/api/chat/record/pull]";
        try {
            log.info("{} params[{}]", msg, chatPullCondition);
            Integer numOfChat = chatRecordBizService
                    .queryChatRecordOfCouple(chatPullCondition);
            return success(numOfChat,
                    data -> log.info("{} 成功 ：result[{}]", msg, numOfChat));
        } catch (Exception ex) {
            handleException(ex, e -> log.error("{} 失败：result[{}]", msg, ex));
            return failureWithMessage(QUERY_FAILURE);
        }
    }
}
